summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorOleksandr Usov <oleksandr.usov@tibra.com>2011-10-21 10:37:53 +0100
committerOleksandr Usov <oleksandr.usov@tibra.com>2011-10-21 10:37:53 +0100
commit310366242244327fbe930f7ae5e86671c735b310 (patch)
tree9a698f516f0514ba48994a86fd6dc51a0a471b85
parent5052e8f8a27c1c302f0914e6aad6c4e8377bd9bc (diff)
downloadbzr-fastimport-310366242244327fbe930f7ae5e86671c735b310.tar.gz
Command-line flag renamed to --dont-squash-empty-commits
-rw-r--r--cmds.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/cmds.py b/cmds.py
index 8b9ef13..0e0eae5 100644
--- a/cmds.py
+++ b/cmds.py
@@ -393,7 +393,7 @@ class cmd_fast_import_filter(Command):
Empty commits (or commits which had all their content filtered out) will
be removed, and so are the references to commits not included in the stream.
Flag --preserve-all-history reverses this behavior and makes it possible to
use fast-import-filter on incremental streams.
:Examples:
@@ -424,19 +424,19 @@ class cmd_fast_import_filter(Command):
Option('user-map', type=str,
help="Path to file containing a map of user-ids.",
),
- Option('preserve-all-history',
+ Option('dont-squash-empty-commits',
help="Preserve all commits and links between them"
),
]
encoding_type = 'exact'
def run(self, source=None, verbose=False, include_paths=None,
- exclude_paths=None, user_map=None, preserve_all_history=False):
+ exclude_paths=None, user_map=None, dont_squash_empty_commits=False):
load_fastimport()
from fastimport.processors import filter_processor
params = {
'include_paths': include_paths,
'exclude_paths': exclude_paths,
- 'preserve_all_history': preserve_all_history
+ 'squash_empty_commits': not dont_squash_empty_commits,
}
from fastimport import parser
stream = _get_source_stream(source)
@@ -393,7 +393,7 @@ class cmd_fast_import_filter(Command):
Empty commits (or commits which had all their content filtered out) will
be removed, and so are the references to commits not included in the stream.
- Flag --preserve-all-history reverses this behavior and makes it possible to
+ Flag --dont-squash-empty-commits reverses this behavior and makes it possible to
use fast-import-filter on incremental streams.
:Examples: